from ROOT import *
import ROOT
ROOT.gROOT.SetStyle("Plain")
from array import array
import sys
import rootStyle

rootStyle.SetRootStyle()

import stop1Linterp, stopCharminterp
import math
doStop1L = False
if doStop1L == True:
    htupla = stop1Linterp.RetrieveTH2() 
    p8715_d22x1y1= stop1Linterp.RetrieveHEPline()
else:
    htupla = stopCharminterp.RetrieveTH2() 
    p8715_d22x1y1= stopCharminterp.RetrieveHEPline()


### These parameters can be changed to change the scan

###########

def optParsing():
    from optparse import OptionParser
    parser = OptionParser()
    parser.add_option("--Mchi", dest="Mchi", help="Choose a mass of the DM to process: note, not all values are possible",
                      type='int',default=50)

    parser.add_option("--lumi", dest="lumi", help="Integrated luminosity (default 20ifb)",
                      default=20,type="int")
    parser.add_option("--alphalist", dest="alist", help="List of pi fractions to test, comma separated, no spaces. Default 3,4,8",
                      default='3,4,8')
    parser.add_option("--u1min", dest="u1min", help="Min mass for u1, u2 min mass will be chosen 50 GeV heavier.",
                      default=300,type="int")
    parser.add_option("--u1max", dest="u1max", help="Max mass for u1, u2 max mass will be chosen 2* heavier.",
                      default=1000,type="int")
    parser.add_option("--step", dest="step", help="step of the mass scan. (Default 50 GeV).",
                      default=50,type="int")


   
    (config, sys.argv[1:]) = parser.parse_args(sys.argv[1:])

    return config



config = optParsing()
Mchi = config.Mchi
u1m = range(config.u1min,config.u1max,config.step)
u2m = range(config.u1min+50,config.u1max*2,config.step)
alist = [math.pi/float(i) for i in config.alist.split(',')]
lumi = config.lumi*1000





## These are at the moment the only regions implemented for each analysis. Could be worth
## applying a less hard region in the stop1L analysis. 
stopreg = "SRtN_boost"
charreg = "mct150"

stopaccmap = stop1Linterp.RetrieveAcceptance(mchi=Mchi, region=stopreg)
characcmap = stopCharminterp.RetrieveAcceptance(mchi=Mchi, region=charreg)

xsecmap = stop1Linterp.xsecmap

# for now I implemented only one region, but all is set to accept more
# these are model independent upper limit (observed) on signal yield
stopUL = {"SRtN_boost":5}
charmUL = {"mct150":8.9}

import decays_sq



for alpha in alist:
    print 
    print " Next alpha scan starts here ------------------------------------------------"
    print "alpha, u1, u2, BR1(tt), BR2(tt), BR1(cc), BR2(cc), Nsig(tt), Nsig(cc), accepted?"
    for u1 in u1m:
        for du2 in u2m:
            u2 = u1 + du2
            if u1 not in xsecmap:
#                print "outside boundaries, skipping", u1, u2
                continue


            # returns a tuple (charm BR, top BR)
            br1 = decays_sq.Decay_sq1BR(Mchi=Mchi,Msq1=u1,alpha=alpha)
            br2 = decays_sq.Decay_sq2BR(Mchi=Mchi,Msq2=u2,alpha=alpha)

            # calculating tt+met acceptance
            if u2 in xsecmap:
                stopyield = stopaccmap[u1]*xsecmap[u1]*lumi*br1[1]**2+stopaccmap[u2]*xsecmap[u2]*lumi*br2[1]**2

            else: # if u2 beyond the range, assume it does not contribute
                stopyield = stopaccmap[u1]*xsecmap[u1]*lumi*br1[1]**2


            # calculating cc+met acceptance
            if u1 not in characcmap:
                if u1-50 in characcmap and u1+50 in characcmap:
                    # fix spacing of the charm hepdata by linear interpolation between nearby points
                    caccinterp = (characcmap[u1-50]+characcmap[u1+50])/2
            else:
                caccinterp = characcmap[u1]

                

            if u2 in xsecmap:
                if u2 not in characcmap:
                    if u2-50 in characcmap and u2+50 in characcmap:
                        # fix spacing of the charm hepdata by linear interpolation between nearby points
                        caccinterp2 = (characcmap[u2-50]+characcmap[u2+50])/2
                else:
                    caccinterp2 = characcmap[u2]
                
                charyield = caccinterp*xsecmap[u1]*lumi*br1[0]**2+caccinterp2*xsecmap[u2]*lumi*br2[0]**2

            else: # if u2 beyond the range, assume it does not contribute
                charyield = caccinterp*xsecmap[u1]*lumi*br1[0]**2

#            print caccinterp, xsecmap[u1], br1[1], characcmap[u1-50], characcmap[u1+50]
            print round(alpha,2), u1, u2, round(br1[1],2), round(br2[1],2), round(br1[0],2), round(br2[0],2), round(stopyield,1), round(charyield,1), 

            if (stopyield) > stopUL[stopreg] or charyield > charmUL[charreg] :
                print "excluded"
            else:
                print "not excluded"

import sys
sys.exit()

