from ROOT import *
import ROOT
ROOT.gROOT.SetStyle("Plain")
from array import array

import rootStyle

rootStyle.SetRootStyle()


# stop cross sections 8 TeV
xsecmap = {100.:    560.2   *1000,
           125. :   197.3   *1000,
           150. :   80.3    *1000,
           175. :   36.9    *1000,
           200. :   18.5    *1000,
           225. :   9.92    *1000,
           250. :   5.58    *1000,
           275. :   3.28    *1000,
           300. :   2.00    *1000,
           350. :   0.808   *1000,
           400. :   0.357   *1000,
           450. :   0.170   *1000,
           500. :   0.0856  *1000,
           550. :   0.0452  *1000,
           600. :   0.0248  *1000,
           650. :   0.0140  *1000,
           700. :   0.00811 *1000,
           750. :   0.00481 *1000,
           800. :   0.00289 *1000}

def RetrieveHEPline():
    # stopCharm Run 1 result
    xval = array("f", [106.5, 106.5, 150.0, 255.0, 265.0, 295.0, 330.0, 350.0, 385.0, 395.0, 400.0, 425.0, 430.0, 450.0, 473.7, 475.9, 481.5, 485.0, 487.4, 485.0, 485.0])
    xerrminus = array("f", [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0])
    xerrplus = array("f", [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0])
    yval = array("f", [0.0, 5.0, 39.4, 126.4, 136.1, 155.9, 179.3, 196.3, 211.0, 218.2, 222.3, 228.0, 227.6, 196.4, 175.0, 165.0, 125.0, 102.8, 85.0, 5.0, 0.0])
    yerrminus = array("f", [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0])
    yerrplus = array("f", [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0])
    numpoints = 21
    p8786_d7x1y1 = ROOT.TGraphAsymmErrors(numpoints, xval, yval, xerrminus, xerrplus, yerrminus, yerrplus)
    p8786_d7x1y1.SetLineColor(kRed)
    p8786_d7x1y1.SetLineWidth(4)
    p8786_d7x1y1.SetName("/HepData/8786/d7x1y1")
    p8786_d7x1y1.SetTitle("/HepData/8786/d7x1y1")
    return p8786_d7x1y1


def RetrieveTH2():

    h2 = TH2D("h2", "h2", 11, 25, 575, 8, -20, 380)

    h2.SetBinContent(h2.FindBin(100. ,   1.   ), 323846    )
    h2.SetBinContent(h2.FindBin(200. ,   1.   ), 1993      )
    h2.SetBinContent(h2.FindBin(300. ,   1.   ), 178       )
    h2.SetBinContent(h2.FindBin(400. ,   1.   ), 97        )
    h2.SetBinContent(h2.FindBin(500. ,   1.   ), 79        )
    h2.SetBinContent(h2.FindBin(600. ,   1.   ), 70        )
    h2.SetBinContent(h2.FindBin(150. ,   50.  ),  73846    )
    h2.SetBinContent(h2.FindBin(250. ,   50.  ),  500      )
    h2.SetBinContent(h2.FindBin(350. ,   50.  ),  131      )
    h2.SetBinContent(h2.FindBin(450. ,   50.  ),  81       )
    h2.SetBinContent(h2.FindBin(550. ,   50.  ),  75       )
 #   h2.SetBinContent(h2.FindBin(200. ,   75.  ),  11568    )
    h2.SetBinContent(h2.FindBin(300. ,   100. ),   296     )
    h2.SetBinContent(h2.FindBin(400. ,   100. ),   108     )
    h2.SetBinContent(h2.FindBin(500. ,   100. ),   74      )
    h2.SetBinContent(h2.FindBin(600. ,   100. ),   71      )
    h2.SetBinContent(h2.FindBin(250. ,   150. ),   9365    )
    h2.SetBinContent(h2.FindBin(350. ,   150. ),   218     )
    h2.SetBinContent(h2.FindBin(450. ,   150. ),   96      )
    h2.SetBinContent(h2.FindBin(550. ,   150. ),   77      )
    h2.SetBinContent(h2.FindBin(300. ,   200. ),   8737    )
    h2.SetBinContent(h2.FindBin(400. ,   200. ),   177     )
    h2.SetBinContent(h2.FindBin(500. ,   200. ),   87      )
    h2.SetBinContent(h2.FindBin(600. ,   200. ),   71      )
    h2.SetBinContent(h2.FindBin(350. ,   250. ),   5882    )
    h2.SetBinContent(h2.FindBin(450. ,   250. ),   177     )
    h2.SetBinContent(h2.FindBin(550. ,   250. ),   100     )
    h2.SetBinContent(h2.FindBin(400. ,   300. ),   4069    )
    h2.SetBinContent(h2.FindBin(500. ,   300. ),   146     )
    h2.SetBinContent(h2.FindBin(600. ,   300. ),   87      )
    h2.SetBinContent(h2.FindBin(450. ,   350. ),   4037    )
    h2.SetBinContent(h2.FindBin(500. ,   400. ),   2711    )
    h2.SetBinContent(h2.FindBin(600. ,   400. ),   152     )
    h2.SetBinContent(h2.FindBin(600. ,   500. ),   905     )

    h2mu = TH2D("h2mu", "h2mu", 11, 25, 575, 8, -20, 380)


    h2mu.SetBinContent(h2mu.FindBin(100. ,   1.   ), 323846 /xsecmap[100]   )
    h2mu.SetBinContent(h2mu.FindBin(200. ,   1.   ), 1993   /xsecmap[200]   )
    h2mu.SetBinContent(h2mu.FindBin(300. ,   1.   ), 178    /xsecmap[300]   )
    h2mu.SetBinContent(h2mu.FindBin(400. ,   1.   ), 97     /xsecmap[400]   )
    h2mu.SetBinContent(h2mu.FindBin(500. ,   1.   ), 79     /xsecmap[500]   )
    h2mu.SetBinContent(h2mu.FindBin(600. ,   1.   ), 70     /xsecmap[600]   )
    h2mu.SetBinContent(h2mu.FindBin(150. ,   50.  ),  73846 /xsecmap[150]   )
    h2mu.SetBinContent(h2mu.FindBin(250. ,   50.  ),  500   /xsecmap[250]   )
    h2mu.SetBinContent(h2mu.FindBin(350. ,   50.  ),  131   /xsecmap[350]   )
    h2mu.SetBinContent(h2mu.FindBin(450. ,   50.  ),  81    /xsecmap[450]   )
    h2mu.SetBinContent(h2mu.FindBin(550. ,   50.  ),  75    /xsecmap[550]   )
    h2mu.SetBinContent(h2mu.FindBin(300. ,   100. ),   296  /xsecmap[300]   )
    h2mu.SetBinContent(h2mu.FindBin(400. ,   100. ),   108  /xsecmap[400]   )
    h2mu.SetBinContent(h2mu.FindBin(500. ,   100. ),   74   /xsecmap[500]   )
    h2mu.SetBinContent(h2mu.FindBin(600. ,   100. ),   71   /xsecmap[600]   )
    h2mu.SetBinContent(h2mu.FindBin(250. ,   150. ),   9365 /xsecmap[250]   )
    h2mu.SetBinContent(h2mu.FindBin(350. ,   150. ),   218  /xsecmap[350]   )
    h2mu.SetBinContent(h2mu.FindBin(450. ,   150. ),   96   /xsecmap[450]   )
    h2mu.SetBinContent(h2mu.FindBin(550. ,   150. ),   77   /xsecmap[550]   )
    h2mu.SetBinContent(h2mu.FindBin(300. ,   200. ),   8737 /xsecmap[300]   )
    h2mu.SetBinContent(h2mu.FindBin(400. ,   200. ),   177  /xsecmap[400]   )
    h2mu.SetBinContent(h2mu.FindBin(500. ,   200. ),   87   /xsecmap[500]   )
    h2mu.SetBinContent(h2mu.FindBin(600. ,   200. ),   71   /xsecmap[600]   )
    h2mu.SetBinContent(h2mu.FindBin(350. ,   250. ),   5882 /xsecmap[350]   )
    h2mu.SetBinContent(h2mu.FindBin(450. ,   250. ),   177  /xsecmap[450]   )
    h2mu.SetBinContent(h2mu.FindBin(550. ,   250. ),   100  /xsecmap[550]   )
    h2mu.SetBinContent(h2mu.FindBin(400. ,   300. ),   4069 /xsecmap[400]   )
    h2mu.SetBinContent(h2mu.FindBin(500. ,   300. ),   146  /xsecmap[500]   )
    h2mu.SetBinContent(h2mu.FindBin(600. ,   300. ),   87   /xsecmap[600]   )
    h2mu.SetBinContent(h2mu.FindBin(450. ,   350. ),   4037 /xsecmap[450]   )
    h2mu.SetBinContent(h2mu.FindBin(500. ,   400. ),   2711 /xsecmap[500]   )
    h2mu.SetBinContent(h2mu.FindBin(600. ,   400. ),   152  /xsecmap[600]   )
    h2mu.SetBinContent(h2mu.FindBin(600. ,   500. ),   905  /xsecmap[600]   )
                                                            
    
    for j in range(h2mu.GetNbinsY()):
        for i in range(h2mu.GetNbinsX()):

            x=h2mu.GetXaxis().GetBinCenter( i )
            y=h2mu.GetYaxis().GetBinCenter( j )
            if x > 550: continue
            if h2mu.GetBinContent(h2mu.FindBin(x,y)) == 0:

                xwidth = h2mu.GetXaxis().GetBinWidth( i )
                bind = h2mu.GetBinContent(h2mu.FindBin(x-xwidth,y))
                binu = h2mu.GetBinContent(h2mu.FindBin(x+xwidth,y))
                if bind != 0 and binu != 0:
                    h2mu.SetBinContent(h2mu.FindBin(x,y), (bind+binu)/2.)
                
  

    return [h2, h2mu]








def RetrieveAcceptance(mchi = 50, region="mct150"):

    if region == "mct150":
        fullmap = {
            (100.,    1. ):   0.00000225,
            (200.,    1. ):   0.000323,
            (300.,    1. ):   0.00313,
            (400.,    1. ):   0.00580,
            (500.,    1. ):   0.00729,
            (600.,    1. ):   0.00845,
            (150.,    50. ):   0.0000141,
            (200.,    75. ):   0.0000647,
            (250.,    50. ):   0.00117,
            (350.,    50. ):   0.00434,
            (450.,    50. ):   0.00698,
            (550.,    50. ):   0.00773,
            (650.,    50. ):   0.00779,
            (300.,    100. ):   0.00193,
            (400.,    100. ):   0.00525,
            (500.,    100. ):   0.00767,
            (600.,    100. ):   0.00826,
            (250.,    150. ):   0.0000691,
            (350.,    150. ):   0.00255,
            (450.,    150. ):   0.00585,
            (550.,    150. ):   0.00750,
            (650.,    150. ):   0.0103,
            (300.,    200. ):   0.0000731,
            (400.,    200. ):   0.00318,
            (500.,    200. ):   0.00656,
            (600.,    200. ):   0.00826,
            (350.,    250. ):   0.000114,
            (450.,    250. ):   0.00319,
            (550.,    250. ):   0.00675,
            (650.,    250. ):   0.00813,
            (400.,    300. ):   0.000160,
            (500.,    300. ):   0.00392,
            (600.,    300. ):   0.00704,
            (450.,    350. ):   0.000176,
            (500.,    400. ):   0.000234,
            (600.,    400. ):   0.00389,
            }



    smallmap = {}
             
    for i in fullmap:
        if i[1] == mchi:
            smallmap[i[0]] = fullmap[i]

    if len(smallmap) < 1: print "Warning, did you ask a non available chi mass?"
    
    return smallmap

